.. note
You should *NOT* add new change log entries to this file, this
file is managed by towncrier. You *may* edit previous change logs to
fix problems like typo corrections or such.

.. towncrier release notes start

pytest-memray 1.0.0 (2022-04-09)
================================

-  Initial release.
